==> 0.0.1%2B1.tar.gz: lib/models/IR5StaffBtn.dart <==
import 'package:json_annotation/json_annotation.dart';

import "IR5BtnProperties.dart" show IR5BtnProperties;

// --------------------------------------------------------------------------------

part 'IR5StaffBtn.g.dart';

/** PERSO aka Staffs */
@JsonSerializable(explicitToJson: true)
class IR5StaffBtn {
  IR5StaffBtn({
    required this.Nom,
    required this.No,
    required this.Level,
    required this.Language,
    required this.Color,
    required this.Bmp,
    required this.AskPwd,
    required this.NextFrame,
    required this.TblModePOS,
    required this.BtnProp,
    required this.Visible,
    required this.Top,
    required this.Left,
    required this.Height,
    required this.Width,
  });

  factory IR5StaffBtn.fromJson(Map<String, dynamic>? json) => _$IR5StaffBtnFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5StaffBtnToJson(this);

  /** Staff Name */
  @JsonKey(defaultValue: '')
  final String Nom;
  @JsonKey(defaultValue: 0)
  final num No;
  @JsonKey(defaultValue: 0)
  final num /* Number | StaffLevel */ Level;

  /** Language Index :
   * 0 : French (Default)
   * 1 : Dutch
   * 2 : English
   * 3 : German
   * 4 : Spanish
   */
  @JsonKey(defaultValue: '')
  final String Language;

  /** Staff personnal color. Easier to identify which Staff is logged in */
  @JsonKey(defaultValue: '')
  final String Color;

  /** Image Num */
  @JsonKey(defaultValue: 0)
  final num Bmp;
  @JsonKey(defaultValue: true)
  final bool AskPwd;
  @JsonKey(defaultValue: '')
  final String NextFrame;
  @JsonKey(defaultValue: '')
  final String TblModePOS;

  final IR5BtnProperties BtnProp;
  @JsonKey(defaultValue: false)
  final bool Visible;
  @JsonKey(defaultValue: 0)
  final num Top;
  @JsonKey(defaultValue: 0)
  final num Left;
  @JsonKey(defaultValue: 0)
  final num Height;
  @JsonKey(defaultValue: 0)
  final num Width;
}

==> 0.0.2%2B1.tar.gz: lib/models/IR5StaffBtn.dart <==
import 'package:json_annotation/json_annotation.dart';

import "IR5BtnProperties.dart" show IR5BtnProperties;

// --------------------------------------------------------------------------------

part 'IR5StaffBtn.g.dart';

/** PERSO aka Staffs */
@JsonSerializable(explicitToJson: true)
class IR5StaffBtn {
  IR5StaffBtn({
    required this.Nom,
    required this.No,
    required this.Level,
    required this.Language,
    required this.Color,
    required this.Bmp,
    required this.AskPwd,
    required this.NextFrame,
    required this.TblModePOS,
    required this.BtnProp,
    required this.Visible,
    required this.Top,
    required this.Left,
    required this.Height,
    required this.Width,
  });

  factory IR5StaffBtn.fromJson(Map<String, dynamic>? json) =>
      _$IR5StaffBtnFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5StaffBtnToJson(this);

  /** Staff Name */
  @JsonKey(defaultValue: '')
  final String Nom;
  @JsonKey(defaultValue: 0)
  final num No;
  @JsonKey(defaultValue: 0)
  final num /* Number | StaffLevel */ Level;

  /** Language Index :
   * 0 : French (Default)
   * 1 : Dutch
   * 2 : English
   * 3 : German
   * 4 : Spanish
   */
  @JsonKey(defaultValue: '')
  final String Language;

  /** Staff personnal color. Easier to identify which Staff is logged in */
  @JsonKey(defaultValue: '')
  final String Color;

  /** Image Num */
  @JsonKey(defaultValue: 0)
  final num Bmp;
  @JsonKey(defaultValue: true)
  final bool AskPwd;
  @JsonKey(defaultValue: '')
  final String NextFrame;
  @JsonKey(defaultValue: '')
  final String TblModePOS;

  final IR5BtnProperties BtnProp;
  @JsonKey(defaultValue: false)
  final bool Visible;
  @JsonKey(defaultValue: 0)
  final num Top;
  @JsonKey(defaultValue: 0)
  final num Left;
  @JsonKey(defaultValue: 0)
  final num Height;
  @JsonKey(defaultValue: 0)
  final num Width;
}
